pub fn parse_git_stat_records(output: &str) -> Result<Vec<GitStat>, ParseError>Expand description
Parse one or more newline-field GitStat records.
Errors
Returns ParseError if the record has an incomplete field count or any field is invalid.
pub fn parse_git_stat_records(output: &str) -> Result<Vec<GitStat>, ParseError>Parse one or more newline-field GitStat records.
Returns ParseError if the record has an incomplete field count or any field is invalid.